pub enum ReviewGate {
ManagerApproval,
MedicalDocumentReview,
BehaviorReview,
CustomerMessageApproval,
RefundOrDepositException,
}Expand description
Human review gate required before automation may proceed with sensitive work.
Variants
ManagerApproval
Manager approval outcome in the automation authority or human-review policy.
MedicalDocumentReview
Medical document review outcome in the automation authority or human-review policy.
BehaviorReview
Behavior review outcome in the automation authority or human-review policy.
CustomerMessageApproval
Customer message approval outcome in the automation authority or human-review policy.
RefundOrDepositException
Refund or deposit exception outcome in the automation authority or human-review policy.